@@ -1,7 +1,7 @@
 package YAML::LoadBundle;
 # ABSTRACT: Load a directory of YAML files as a bundle
 use version;
-our $VERSION = 'v0.4.2'; # VERSION
+our $VERSION = 'v0.4.3'; # VERSION
 
 use base qw(Exporter);
 use warnings;
@@ -131,6 +131,41 @@ my $deep_merge = sub {
     ) };
 };
 
+my $clone_merge = sub {
+
+    my ($left, $right) = @_;
+
+    if (reftype($left) eq 'HASH' && reftype($right) eq 'HASH')
+    {
+        my %seen;
+
+        foreach my $key (keys %$left)
+        {
+            my $clone = $left->{$key};
+
+            die "-clone of $key is not a hash\n"
+                unless reftype($clone) eq "HASH";
+
+            my $list = delete $clone->{$key};
+
+            die "-clone of $key is missing a list of keys under the same key\n"
+                unless $list && reftype($list) eq 'ARRAY';
+
+            foreach my $cloned_key (@$list)
+            {
+                die "-clone key $cloned_key must appear only once.\n"
+                    if $seen{$cloned_key}++;
+
+                $right->{$cloned_key} = $clone;
+            }
+        }
+
+        return %$right;
+    }
+
+    die "-clone must appear in a hash, and contain a hash.\n";
+};
+
 # in order of priority:
 my @SPECIAL = qw(
     -merge
@@ -138,6 +173,7 @@ my @SPECIAL = qw(
     -export
     import
     -import
+    -clone
 );
 my %SPECIAL = (
     -import => $shallow_merge,
@@ -145,6 +181,7 @@ my %SPECIAL = (
     -export => $shallow_merge,
     export  => $shallow_merge,
     -merge  => $deep_merge,
+    -clone  => $clone_merge,
 );
 
 # Note: This used to add a (heavy) dependency on Data::Visitor
@@ -474,7 +511,7 @@ YAML::LoadBundle - Load a directory of YAML files as a bundle
 
 =head1 VERSION
 
-version v0.4.2
+version v0.4.3
 
 =head1 SYNOPSIS
 
@@ -484,7 +521,7 @@ version v0.4.2
 
 =head1 DESCRIPTION
 
-Adds additonal features to YAML::XS to allow splitting a YAML file into
+Adds additional features to YAML::XS to allow splitting a YAML file into
 multiple files in a common directory.
 This helps with readability when the file is large.
 
@@ -538,7 +575,11 @@ shallow merge
 
 deep merge (see L<Hash::Merge::Simple>)
 
-=item * <-flatten>
+=item * C<-clone>
+
+clones intermediate hash keys, see L</Cloning intermediate hash keys> below.
+
+=item * C<-flatten>
 
     some_key: { -flatten: [*SomeArrayRef, *SomeOtherArrayRef] }
 
@@ -572,6 +613,88 @@ Instead of a hash reference, any of these keys may contain an array reference
 of hash references, in which case those hash references are merged using
 whatever strategy normally applies (e.g. deep merge for C<-merge>).
 
+=head4 Cloning intermediate hash keys
+
+C<-clone> provides a way to repeat intermediate nodes in hashes:
+
+  apple:
+    -clone:
+       letters:
+         letters: &letters
+           - a
+           - b
+         d: e
+         f: g
+       numbers:
+         numbers:
+           - 1
+           - 2
+         quattro: 4
+         cinco:   5
+    golf: g
+    hotel: h
+
+  banana:
+    -clone:
+      letters:
+         letters:  *letters
+         h: i
+         j: k
+
+This results a hash with "d" and "f" keys getting cloned inside another
+hash using keys "a" and "b" for each cloned copy; "quattro" and "cinco"
+are also cloned under keys "1" and "2", together with "g" and "h" which are
+just along for the ride.
+
+The same "a" and "b" keys get referenced, without duplication, and used
+for intermediate keys in a different part of the hash.
+
+So the resulting hash would be:
+
+   'apple' => {
+         'a' => {
+             'd' => 'e',
+             'f' => 'g',
+          },
+         'b' => {
+             'd' => 'e',
+             'f' => 'g',
+          },
+         '1' => {
+             'quattro' => '4',
+             'cinco' => '5',
+         },
+         '2' => {
+             'quattro' => '4',
+             'cinco' => '5',
+         },
+         'golf' => 'g',
+         'hotel' => 'h',
+    },
+    'banana' => {
+         'a' => {
+             'h' => 'i',
+             'j' => 'k',
+         },
+         'b' => {
+             'h' => 'i',
+             'j' => 'k',
+         },
+     },
+
+Formally:
+
+C<-clone> itself must be a hash key, and contains a hash, the "clone" hash,
+with one or more keys. Each value of those keys is a subhash that must
+have a key with the same name as its parent key in the "clone" hash.
+This key's value must be a list, and the rest of the subhash gets cloned,
+one for each value in the list, and placed into the C<-clone> hash,
+with each value in the list being its key.
+
+This provides the means to have a single specification of a list and
+then repeat it (via the usual YAML "&" and "*") references but insert them
+as intermediate hash keys.
+
 =head3 load_yaml_bundle
 
   load_yaml_bundle($path, \%options)
@@ -719,7 +842,7 @@ Grant Street Group <developers@grantstreet.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 - 2020 by Grant Street Group.
+This software is Copyright (c) 2016 - 2021 by Grant Street Group.
 
 This is free software, licensed under:
 
